@@ -43,6 +43,7 @@
 #include "gst/gst-i18n-plugin.h"
 
 #include "pbutils.h"
+#include "pbutils-private.h"
 
 #include <string.h>
 
@@ -69,11 +70,13 @@ static const FormatInfo formats[] = {
   {"application/x-apetag", N_("APE tag"), FLAG_CONTAINER},
   {"application/x-icy", N_("ICY internet radio"), FLAG_CONTAINER},
   {"application/x-3gp", "3GP", FLAG_CONTAINER},
+  {"application/x-pn-realaudio", "RealAudio", FLAG_CONTAINER},
   {"application/x-yuv4mpeg", "Y4M", FLAG_CONTAINER},
   {"multipart/x-mixed-replace", "Multipart", FLAG_CONTAINER},
   {"video/x-fli", "FLI/FLC/FLX Animation", FLAG_CONTAINER},
   {"video/x-flv", "Flash", FLAG_CONTAINER},
   {"video/x-matroska", "Matroska", FLAG_CONTAINER},
+  {"video/webm", "WebM", FLAG_CONTAINER},
   {"video/x-ms-asf", "Advanced Streaming Format (ASF)", FLAG_CONTAINER},
   {"video/x-msvideo", "AVI", FLAG_CONTAINER},
   {"video/x-quicktime", "Quicktime", FLAG_CONTAINER},
@@ -98,6 +101,7 @@ static const FormatInfo formats[] = {
   {"audio/x-amr-nb-sh", "Adaptive Multi Rate NarrowBand (AMR-NB)", 0},
   {"audio/x-amr-wb-sh", "Adaptive Multi Rate WideBand (AMR-WB)", 0},
   {"audio/x-au", "Sun .au", 0},
+  {"audio/x-celt", "Constrained Energy Lapped Transform (CELT)", 0},
   {"audio/x-cinepak", "Cinepak Audio", 0},
   {"audio/x-dpcm", "DPCM", 0},
   {"audio/x-dts", "DTS", 0},
@@ -155,6 +159,7 @@ static const FormatInfo formats[] = {
   {"video/x-cirrus-logic-accupak", "Cirrus Logipak AccuPak", 0},
   {"video/x-compressed-yuv", N_("CYUV Lossless"), 0},
   {"video/x-dirac", "Dirac", 0},
+  {"video/x-dnxhd", "Digital Nonlinear Extensible High Definition (DNxHD)", 0},
   {"video/x-dvd-subpicture", "DVD subpicture", 0},
   {"video/x-ffv", N_("FFMpeg v1"), 0},
   {"video/x-flash-screen", "Flash Screen Video", 0},
@@ -165,6 +170,7 @@ static const FormatInfo formats[] = {
   {"video/x-jpeg", "Motion JPEG", 0},
   /* { "video/x-jpeg-b", "", 0 }, does this actually exist? */
   {"video/x-loco", "LOCO Lossless", 0},
+  {"video/x-mimic", "MIMIC", 0},
   {"video/x-mjpeg", "Motion-JPEG", 0},
   {"video/x-mjpeg-b", "Motion-JPEG format B", 0},
   {"video/mpegts", "MPEG-2 Transport Stream", FLAG_CONTAINER},
@@ -188,7 +194,9 @@ static const FormatInfo formats[] = {
   {"video/x-vp5", "On2 VP5", 0},
   {"video/x-vp6", "On2 VP6", 0},
   {"video/x-vp6-flash", "On2 VP6/Flash", 0},
+  {"video/x-vp6-alpha", "On2 VP6 with alpha", 0},
   {"video/x-vp7", "On2 VP7", 0},
+  {"video/x-vp8", "VP8", 0},
   {"video/x-xvid", "XVID MPEG-4", 0},
   {"video/x-zlib", "Lossless zlib video", 0},
   {"video/x-zmbv", "Zip Motion Block video", 0},
@@ -218,6 +226,7 @@ static const FormatInfo formats[] = {
   {"image/x-tga", "TGA", 0},
 
   /* subtitle formats with static descriptions */
+  {"application/x-ass", "ASS", 0},
   {"application/x-subtitle-sami", N_("Sami subtitle format"), 0},
   {"application/x-subtitle-tmplayer", N_("TMPlayer subtitle format"), 0},
   {"application/x-kate", "Kate", 0},
@@ -775,23 +784,27 @@ gchar *
 gst_pb_utils_get_decoder_description (const GstCaps * caps)
 {
   gchar *str, *ret;
+  GstCaps *tmp;
 
   g_return_val_if_fail (caps != NULL, NULL);
   g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
-  g_return_val_if_fail (gst_caps_is_fixed (caps), NULL);
+
+  tmp = copy_and_clean_caps (caps);
+
+  g_return_val_if_fail (gst_caps_is_fixed (tmp), NULL);
 
   /* special-case RTP caps */
-  if (caps_are_rtp_caps (caps, "video", &str)) {
+  if (caps_are_rtp_caps (tmp, "video", &str)) {
     ret = g_strdup_printf (_("%s video RTP depayloader"), str);
-  } else if (caps_are_rtp_caps (caps, "audio", &str)) {
+  } else if (caps_are_rtp_caps (tmp, "audio", &str)) {
     ret = g_strdup_printf (_("%s audio RTP depayloader"), str);
-  } else if (caps_are_rtp_caps (caps, "application", &str)) {
+  } else if (caps_are_rtp_caps (tmp, "application", &str)) {
     ret = g_strdup_printf (_("%s RTP depayloader"), str);
   } else {
     const FormatInfo *info;
 
-    str = gst_pb_utils_get_codec_description (caps);
-    info = find_format_info (caps);
+    str = gst_pb_utils_get_codec_description (tmp);
+    info = find_format_info (tmp);
     if (info != NULL && (info->flags & FLAG_CONTAINER) != 0) {
       ret = g_strdup_printf (_("%s demuxer"), str);
     } else {
@@ -800,6 +813,7 @@ gst_pb_utils_get_decoder_description (const GstCaps * caps)
   }
 
   g_free (str);
+  gst_caps_unref (tmp);
 
   return ret;
 }
@@ -823,23 +837,25 @@ gchar *
 gst_pb_utils_get_encoder_description (const GstCaps * caps)
 {
   gchar *str, *ret;
+  GstCaps *tmp;
 
   g_return_val_if_fail (caps != NULL, NULL);
   g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
-  g_return_val_if_fail (gst_caps_is_fixed (caps), NULL);
+  tmp = copy_and_clean_caps (caps);
+  g_return_val_if_fail (gst_caps_is_fixed (tmp), NULL);
 
   /* special-case RTP caps */
-  if (caps_are_rtp_caps (caps, "video", &str)) {
+  if (caps_are_rtp_caps (tmp, "video", &str)) {
     ret = g_strdup_printf (_("%s video RTP payloader"), str);
-  } else if (caps_are_rtp_caps (caps, "audio", &str)) {
+  } else if (caps_are_rtp_caps (tmp, "audio", &str)) {
     ret = g_strdup_printf (_("%s audio RTP payloader"), str);
-  } else if (caps_are_rtp_caps (caps, "application", &str)) {
+  } else if (caps_are_rtp_caps (tmp, "application", &str)) {
     ret = g_strdup_printf (_("%s RTP payloader"), str);
   } else {
     const FormatInfo *info;
 
-    str = gst_pb_utils_get_codec_description (caps);
-    info = find_format_info (caps);
+    str = gst_pb_utils_get_codec_description (tmp);
+    info = find_format_info (tmp);
     if (info != NULL && (info->flags & FLAG_CONTAINER) != 0) {
       ret = g_strdup_printf (_("%s muxer"), str);
     } else {
@@ -848,6 +864,7 @@ gst_pb_utils_get_encoder_description (const GstCaps * caps)
   }
 
   g_free (str);
+  gst_caps_unref (tmp);
 
   return ret;
 }
@@ -937,17 +954,19 @@ gst_pb_utils_get_codec_description (const GstCaps * caps)
 {
   const FormatInfo *info;
   gchar *str, *comma;
+  GstCaps *tmp;
 
   g_return_val_if_fail (caps != NULL, NULL);
   g_return_val_if_fail (GST_IS_CAPS (caps), NULL);
-  g_return_val_if_fail (gst_caps_is_fixed (caps), NULL);
+  tmp = copy_and_clean_caps (caps);
+  g_return_val_if_fail (gst_caps_is_fixed (tmp), NULL);
 
-  info = find_format_info (caps);
+  info = find_format_info (tmp);
 
   if (info) {
-    str = format_info_get_desc (info, caps);
+    str = format_info_get_desc (info, tmp);
   } else {
-    str = gst_caps_to_string (caps);
+    str = gst_caps_to_string (tmp);
 
     /* cut off everything after the media type, if there is anything */
     if ((comma = strchr (str, ','))) {
@@ -959,6 +978,7 @@ gst_pb_utils_get_codec_description (const GstCaps * caps)
 
     GST_WARNING ("No description available for media type: %s", str);
   }
+  gst_caps_unref (tmp);
 
   return str;
 }
